@@ -205,11 +205,11 @@ class FDBDatacube(Datacube):
                 original_fdb_node_range_vals = []
                 new_current_start_idx = []
                 for j, idx in enumerate(sub_lat_idxs):
-                    if idx not in seen_indices:
+                    if idx.tolist() not in seen_indices:
                         # NOTE: need to remove it from the values in the corresponding tree node
                         # NOTE: need to read just the range we give to gj
                         original_fdb_node_range_vals.append(actual_fdb_node[0].values[j])
-                        seen_indices.add(idx)
+                        seen_indices.add(idx.tolist())
                         new_current_start_idx.append(idx)
                 if original_fdb_node_range_vals != []:
                     actual_fdb_node[0].values = tuple(original_fdb_node_range_vals)
@@ -227,17 +227,25 @@ class FDBDatacube(Datacube):
             first_ax_name = requests.children[0].axis.name
             second_ax_name = requests.children[0].children[0].axis.name
 
-            if first_ax_name not in self.nearest_search.keys() or second_ax_name not in self.nearest_search.keys():
+            axes_in_nearest_search = [
+                first_ax_name not in self.nearest_search.keys(),
+                second_ax_name not in self.nearest_search.keys(),
+            ]
+
+            if all(not item for item in axes_in_nearest_search):
                 raise Exception("nearest point search axes are wrong")
 
             second_ax = requests.children[0].children[0].axis
 
-            nearest_pts = [
-                [lat_val, second_ax._remap_val_to_axis_range(lon_val)]
-                for (lat_val, lon_val) in zip(
-                    self.nearest_search[first_ax_name][0], self.nearest_search[second_ax_name][0]
-                )
-            ]
+            nearest_pts = self.nearest_search.get((first_ax_name, second_ax_name), None)
+            if nearest_pts is None:
+                nearest_pts = self.nearest_search.get((second_ax_name, first_ax_name), None)
+                for i, pt in enumerate(nearest_pts):
+                    nearest_pts[i] = [pt[1], pt[0]]
+
+            transformed_nearest_pts = []
+            for point in nearest_pts:
+                transformed_nearest_pts.append([point[0], second_ax._remap_val_to_axis_range(point[1])])
 
             found_latlon_pts = []
             for lat_child in requests.children:
@@ -246,7 +254,7 @@ class FDBDatacube(Datacube):
 
             # now find the nearest lat lon to the points requested
             nearest_latlons = []
-            for pt in nearest_pts:
+            for pt in transformed_nearest_pts:
                 nearest_latlon = nearest_pt(found_latlon_pts, pt)
                 nearest_latlons.append(nearest_latlon)
 
